@@ -457,7 +457,6 @@ MUIMSessionClose(MUIMSessionHandle inSessionHandle)
     (*inSessionHandle)->fSegments = NULL;
     (*inSessionHandle)->fSegmentCount = 0;
 
-    uim_release_context((*inSessionHandle)->fUC);
     DisposeHandle((Handle) inSessionHandle);
   }
 }
@@ -703,16 +702,12 @@ MUIMSetInputMode(MUIMSessionHandle inSessionHandle, CFStringRef inInputMode)
 #if 0
       UInt32 i;
       for (i = 0; i < gNumSession; i++) {
-        BlockUpdatePreedit();
         uim_press_key((*gSessionList[i])->fUC, UKey_Private1, 0);
         uim_release_key((*gSessionList[i])->fUC, UKey_Private1, 0);
-        UnblockUpdatePreedit();
       }
 #else
-      BlockUpdatePreedit();
       uim_press_key((*inSessionHandle)->fUC, UKey_Private1, 0);
       uim_release_key((*inSessionHandle)->fUC, UKey_Private1, 0);
-      UnblockUpdatePreedit();
 #endif
     }
     else if (!CFStringCompare(inInputMode,
@@ -734,16 +729,12 @@ MUIMSetInputMode(MUIMSessionHandle inSessionHandle, CFStringRef inInputMode)
 #if 0
       UInt32 i;
       for (i = 0; i < gNumSession; i++) {
-        BlockUpdatePreedit();
         uim_press_key((*gSessionList[i])->fUC, UKey_Private2, 0);
         uim_release_key((*gSessionList[i])->fUC, UKey_Private2, 0);
-        UnblockUpdatePreedit();
       }
 #else
-      BlockUpdatePreedit();
       uim_press_key((*inSessionHandle)->fUC, UKey_Private2, 0);
       uim_release_key((*inSessionHandle)->fUC, UKey_Private2, 0);
-      UnblockUpdatePreedit();
 #endif
     }
 
