@@ -61,10 +61,6 @@ extern Boolean gActiveProp;
 extern Boolean gEnableModeTips;
 extern Boolean gCandVertical;
 
-static Boolean gBlockUpdatePreedit = false;
-
-#pragma mark -
-
 static void
 AddPreeditSegment(MUIMSessionHandle inHandle, int inAttr,
                   const char *inStr);
@@ -185,9 +181,7 @@ UIMPreeditUpdate(void *ptr)
   DEBUG_PRINT("UIMPreeditUpdate()\n");
 #endif
 
-  // Avoid a crash when Firefox is launched with uim(Japanese)
-  if (!gBlockUpdatePreedit || (*handle)->fSegmentCount > 0)
-    MUIMUpdateActiveInputArea(handle, false);
+  MUIMUpdateActiveInputArea(handle, FALSE);
 }
 
 /**
@@ -564,7 +558,7 @@ ParseHelperString(const char *str)
   else if (strncmp("prop_label_update", str, 17) == 0) {
   }
   else if (strncmp("focus_in", str, 8) == 0) {
-    gActiveProp = false;
+    gActiveProp = FALSE;
     //DEBUG_PRINT("deactivate prop\n");
   }
 }
@@ -611,7 +605,7 @@ UIMHelperDisconnect()
   gUimSock = NULL;
 
 #ifdef NEW_HELPER
-  gUimHelperConnected = false;
+  gUimHelperConnected = FALSE;
 #else
   gUimFD = -1;
 #endif
@@ -745,15 +739,3 @@ GetPreeditString(MUIMSessionHandle inHandle, UniCharPtr *outStr,
   else
     free(str);
 }
-
-void
-BlockUpdatePreedit()
-{
-  gBlockUpdatePreedit = true;
-}
-
-void
-UnblockUpdatePreedit()
-{
-  gBlockUpdatePreedit = false;
-}
